package VMOMI::DrsRecommendationReasonCode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
